@@ -17,7 +17,7 @@
 # Another check for README-alpha support.  This time it is requested
 # from configure.ac.  Report from Akim Demaille.
 
-. test-init.sh
+. ./defs || exit 1
 
 cat > configure.ac << 'END'
 AC_INIT([alpha], [1.0b])
