@@ -22,7 +22,7 @@
 # installdirs is missing this.  Ideally this would be an automatic
 # feature of any exported target.
 
-. test-init.sh
+. ./defs || exit 1
 
 echo AC_OUTPUT >> configure.ac
 
