@@ -15,9 +15,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Check parallel-tests interactions with "make -n".
-# See also sister test 'parallel-tests-dry-run-2.test'.
+# See also sister test 'parallel-tests-dry-run-2.sh'.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 echo AC_OUTPUT >> configure.ac
 
@@ -82,7 +82,7 @@ END
 
 chmod a+x foo.test bar.test
 
-$MAKE check && Exit 1
+$MAKE check && exit 1
 
 for targ in recheck clean mostlyclean distclean; do
   $MAKE -n "$targ"
