@@ -16,7 +16,7 @@
 
 # Test '+=' functionality.
 
-. test-init.sh
+. ./defs || exit 1
 
 cat > Makefile.am << 'END'
 data_DATA = zar
