@@ -17,7 +17,7 @@
 # Test that POSIX variable expansion '$(var:str=rpl)' works when used
 # with the SCRIPTS primary.
 
-. test-init.sh
+. ./defs || exit 1
 
 cat >> configure.ac << 'END'
 AC_OUTPUT
