@@ -18,7 +18,7 @@
 # From Robert Collins.
 
 required=cc
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat >> configure.ac << 'END'
 AC_CONFIG_FILES([generic/Makefile])
