@@ -18,7 +18,7 @@
 #  - we shouldn't spuriously recognize as TAP result numbers what it
 #    not, even if it seems pretty close
 
-. test-init.sh
+. ./defs || exit 1
 
 . tap-setup.sh
 
