@@ -16,7 +16,7 @@
 
 # Check that target clashes are diagnosed.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
